@@ -1,6 +1,5 @@
 from abc import ABC, abstractmethod
 import json
-from t2wml.utils.debug_logging import basic_debug, t2wml_log
 import yaml
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.mapping.statements import EvaluatedStatement, PartialStatement, StatementError
@@ -11,6 +10,7 @@ from t2wml.input_processing.clean_yaml_parsing import get_cleaned_dataframe
 from t2wml.input_processing.annotation_parsing import Annotation
 from t2wml.input_processing.utils import string_is_valid
 from t2wml.spreadsheets.conversions import to_excel
+from t2wml.utils.debug_logging import basic_debug
 
 class StatementMapper(ABC):
     """an abstract class for creating statementmapper classes. refer to the api documentation for more details.
@@ -39,7 +39,6 @@ class StatementMapper(ABC):
         i=0
 
         for col, row in self.iterator():
-            t2wml_log.debug(f"loop in get_statements: col {col} row {row}")
             i+=1
             if i<start:
                 continue
@@ -73,14 +72,13 @@ class YamlMapper(StatementMapper):
         self.file_path = file_path
         self.yaml_data = validate_yaml(file_path)
 
-    @basic_debug
     def do_init(self, sheet, wikifier):
         if self.yaml_data.get("cleaningMapping"):
             new_df=get_cleaned_dataframe(sheet, self.yaml_data["cleaningMapping"])
             sheet.cleaned_data=new_df
         update_bindings(item_table=wikifier.item_table, sheet=sheet)
         
-    @basic_debug
+
     def get_cell_statement(self, sheet, wikifier, col, row, do_init=True):
         if do_init:
             self.do_init(sheet, wikifier)
@@ -110,21 +108,21 @@ class AnnotationMapper(YamlMapper):
         self.init_annotation(file_path)
         if not self.annotation.potentially_enough_annotation_information:
             self.get_statements=self.empty_get_statements #override get_statements to not return anything
-    @basic_debug
+    
     def init_annotation(self, file_path):
         self.file_path = file_path
         with open(file_path, 'r') as f:
             annotation_blocks_arr=json.load(f)
         self.annotation=Annotation(annotation_blocks_arr)
 
-    @basic_debug
+
     def do_init(self, sheet, wikifier):
         item_table=wikifier.item_table
         update_bindings(item_table=item_table, sheet=sheet)
         yamlContent=self.annotation.generate_yaml(sheet=sheet, item_table=item_table)[0]
         self.yaml_data = yaml.safe_load(yamlContent)
 
-    @basic_debug
+    
     def empty_get_statements(self, sheet, wikifier, *args, **kwargs):
         statements = {}
         cell_errors = []
@@ -139,7 +137,7 @@ class PartialAnnotationMapper(AnnotationMapper):
         self.init_annotation(file_path)
         if not self.annotation.data_annotations:
             self.get_statements=self.empty_get_statements
-    @basic_debug
+
     def get_cell_statement(self, sheet, wikifier, col, row, do_init=True):
         if do_init:
             self.do_init(sheet, wikifier)
