@@ -1,5 +1,4 @@
 from pathlib import Path
-from t2wml.utils.debug_logging import basic_debug, with_args_debug
 import pandas as pd
 import json
 from t2wml.settings import t2wml_settings
@@ -9,6 +8,7 @@ from t2wml.spreadsheets.conversions import to_excel
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from collections.abc import Mapping
 from io import StringIO
+from t2wml.utils.debug_logging import basic_debug
 
 def get_cache_class():
     cache_class = FakeCacher
@@ -71,16 +71,12 @@ class Sheet:
             sc = cache_class(data_file_path, sheet_name)
             self.raw_data = sc.get_sheet()
     
-    def __repr__(self):
-        return "<Sheet: "+self.name+">"
-    
     @property
     def data(self):
         if self.cleaned_data is not None:
             return self.cleaned_data
         return self.raw_data
 
-    #@with_args_debug
     def __getitem__(self, params):
         try:
             return self.data.iloc[params]
@@ -110,7 +106,6 @@ class Sheet:
                     sheet_name=self.name)
 
     @staticmethod
-    @basic_debug
     def from_json(in_json):
         cleaned=in_json.pop("cleaned")
         if cleaned:
